import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The world where all the finch's demo components are stored.
 * 
 * @author Michael Berry
 * @version 01/12/10
 */
public class FinchWorld  extends World
{

    private Slider redSlider, greenSlider, blueSlider;
    private Slider xSlider, ySlider, zSlider;

    public FinchWorld()
    {    
        // Create a new world with 600x400 cells with a cell size of 1x1 pixels.
        super(600, 400, 1); 
        prepare();
    }
    
    /**
     * Manage the sliders.
     */
    public void act() {
        GreenFinch.get().setLED(new java.awt.Color(redSlider.getValue()*255/100, greenSlider.getValue()*255/100, blueSlider.getValue()*255/100));
        int xAccel = (int)((GreenFinch.get().getXAcceleration()+1.5)*33);
        xSlider.setValue(xAccel);
        int yAccel = (int)((GreenFinch.get().getYAcceleration()+1.5)*33);
        ySlider.setValue(yAccel);
        int zAccel = (int)((GreenFinch.get().getZAcceleration()+1.5)*33);
        zSlider.setValue(zAccel);
    }

    /**
     * Start the finch when the scenario starts. Don't remove this!!
     */
    @Override
    public void started() {
        GreenFinch.get().start();
    }

    /**
     * Stops the finch when the scenario stops. Don't remove this!!
     */
    @Override
    public void stopped() {
        GreenFinch.get().stop();
    }

    /**
     * Prepare the world for the start of the program. That is: create the initial
     * objects and add them to the world.
     */
    private void prepare()
    {
        FinchThermometer thermometer = new FinchThermometer();
        addObject(thermometer, 271, 177);
        thermometer.setLocation(81, 175);
        redSlider = new Slider();
        greenSlider = new Slider();
        blueSlider = new Slider();
        addObject(new Label("Red: "),145,63);
        addObject(new Label("Green: "),145,93);
        addObject(new Label("Blue: "),145,123);
        addObject(new Label("Light Control:"),275,33);
        addObject(redSlider, 275, 63);
        addObject(greenSlider, 275, 93);
        addObject(blueSlider, 275, 123);
        addObject(new UpArrow(),250,180);
        addObject(new DownArrow(),250,320);
        addObject(new LeftArrow(),170,250);
        addObject(new RightArrow(),330,250);
        xSlider = new Slider();
        ySlider = new Slider();
        zSlider = new Slider();
        xSlider.showValue(false);
        ySlider.showValue(false);
        zSlider.showValue(false);
        addObject(new Label("Acceleration:"),495,33);
        addObject(new Label("X: "),375,63);
        addObject(new Label("Y: "),375,93);
        addObject(new Label("Z: "),375,123);
        addObject(xSlider, 495, 63);
        addObject(ySlider, 495, 93);
        addObject(zSlider, 495, 123);
        addObject(new LeftBump(),445,195);
        addObject(new RightBump(),515,195);
        addObject(new LeftLight(),410,285);
        addObject(new AverageLight(),480,285);
        addObject(new RightLight(),550,285);

        addObject(new Label("Buzz!! "),445,368);
        addObject(new Buzzer(),480,360);

        addObject(new Label("Use the   "), 255,250);
        addObject(new Label("arrow keys!"), 250,265);
    }
}
