import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import greenfoot.Color;

/**
 * Moves the Finch if light is below threshhold, otherwise it stops moving.
 * 
 * @author Michael Berry 
 * @version 6/10/2011
 */
public class FinchMover  extends Actor
{
    public static final int COUNTER_TIME = 100;
    private int changeCounter = COUNTER_TIME;
    private int threshold = 50;
    
    /**
     * Act - do whatever the FinchMover wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        GreenFinch finch = GreenFinch.get();
        // If there is light, set the LED to green and motors to off
        if(checkLight()) {
            finch.setWheelSpeeds(0,0);
            finch.setLED(java.awt.Color.GREEN);
            return;
        }
        // Change counter means that the Finch will start moving at a random amount of time after the Finch has found light
        changeCounter--;
        // Set the LED to red if the light level is below threshhold
        finch.setLED(java.awt.Color.RED);
        if(changeCounter==0) {
            changeCounter = COUNTER_TIME;
            // Move in a random direction
            finch.setWheelSpeeds(Greenfoot.getRandomNumber(100),Greenfoot.getRandomNumber(100));
        }
    }
    
    public void setThreshold(int threshold) {
        this.threshold = threshold;
    }
    
    
    /* Checks to get the average light level and returns a boolean if it is more than the threshold */
    private boolean checkLight() {
        GreenfootImage image = new GreenfootImage(70,30);
        int lightLevel = GreenFinch.get().getLightLevel();
        boolean result = lightLevel>=threshold;
        // Sets the image of the rectangle red or green based on meeting threshhold
        if(result) {
            image.setColor(Color.GREEN);
        }
        else {
            image.setColor(Color.RED);
        }
        image.fillRect(0,0,70,30);
        image.setColor(Color.WHITE);
        // Prints the current light level
        image.drawString("Light: " + lightLevel, 11,19);
        setImage(image);
        return result;
    }
    
}
